==> haskell-mmap-0.5.9-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-JmIqi6ZDtlL1Sp81OZdVqe
key:                  mmap-0.5.9-JmIqi6ZDtlL1Sp81OZdVqe
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  cd40914f5e78e339d1d8ad2af873d3a4
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-9.0.1/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/mmap-0.5.9
hs-libraries:         HSmmap-0.5.9-JmIqi6ZDtlL1Sp81OZdVqe
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmap-0.5.9-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mmap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mmap
version:              0.5.9
visibility:           public
id:                   mmap-0.5.9-2PmpclPM54rLuoCJMVeXaO
key:                  mmap-0.5.9-2PmpclPM54rLuoCJMVeXaO
license:              BSD-3-Clause
copyright:            2008-2012, Gracjan Polak
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Gracjan Polak <gracjanpolak@gmail.com>
stability:            stable
synopsis:             Memory mapped files for POSIX and Windows
description:
    This library provides a wrapper to mmap(2) or MapViewOfFile,
    allowing files or devices to be lazily loaded into memory as
    strict or lazy ByteStrings, ForeignPtrs or plain Ptrs, using
    the virtual memory subsystem to do on-demand loading.
    Modifications are also supported.

category:             System
abi:                  3752239b3f2793a690f6cfac8a81a6f5
exposed:              True
exposed-modules:      System.IO.MMap
import-dirs:          /usr/lib/ghc-9.0.2/site-local/mmap-0.5.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mmap-0.5.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/mmap-0.5.9
hs-libraries:         HSmmap-0.5.9-2PmpclPM54rLuoCJMVeXaO
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-mmap/html/mmap.haddock
haddock-html:         /usr/share/doc/haskell-mmap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
